# libpythonpro
Módulo para exemplificar a construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto 

Link para o curso [Python Pro](https://pythonpro.com.br/)

Suportada versão 3 de Python

Para instalar:
``` console
py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt

```

Para conferir qualidade do código:

``` console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 4. GitHub Actions CI